@@ -20,4 +20,8 @@ QUE_DIR=${ROOT}/que
 find ${QUE_DIR}/daemon_error -type f -mtime +30 >> ${LOG} 2>&1
 find ${QUE_DIR}/daemon_error -type f -mtime +30 | xargs rm -f  >> ${LOG} 2>&1
 
+#daemon_status que
+find ${QUE_DIR}/server_status -type f -mtime +30 >> ${LOG} 2>&1
+find ${QUE_DIR}/server_status -type f -mtime +30 | xargs rm -f  >> ${LOG} 2>&1
+
 exit 0
